from distutils.core import setup
setup(
  name = 'coala-decorators',
  packages = ['coala-decorators'],
  version = '0.1',
  description = 'A collection of useful decorators.',
  author = 'Adrian Zatreanu',
  author_email = 'adrian.zatreanu@eestec.ro',
  url = 'https://github.com/coala-analyzer/coala-decorators',
  download_url = 'https://www.github.com/coala-analyzer/coala-decorators/tarball/0.1',
  keywords = ['coala', 'decorators', 'bears'],
  classifiers = [],
)
